from flask import Flask, jsonify, request, send_from_directory
from flask.views import View
import json

def p(form, files):
    print(form, [x.filename for x in files])
    return {'result': 'success'}

class FlaskHandle(View):
    methods=['POST']
    def __init__(self, callback=p):
        self.app = Flask('backend')
        self.callback = callback

    def dispatch_request(self):
        files = request.files.getlist('file')
        js = request.form['json']
        return jsonify(self.callback(json.loads(js), files))

    def run(self, host="0.0.0.0", port=5020):
        self.app.run(host=host, port=port)

class Backend():
    def __init__(self, callback=p):
        self.app = Flask('backend')
        self.callback = callback
        self.app.add_url_rule('/', view_func=FlaskHandle.as_view('backend', callback=callback))

    def file_return(self, path, file):
        """Provide a method to return a file instead
        of a string"""
        return send_from_directory(path, file)

    def run(self, host="0.0.0.0", port=5020):
        self.app.run(host=host, port=port)



from setuptools import setup

setup(name='izzati',
      version='1.0.0',
      description='A simple, multi-language frontend to backend communication library',
      classifiers=[
        'Development Status :: 5 - Production/Stable',
        'License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)',
        'Programming Language :: Python :: 3 :: Only'
      ],
      url='http://github.com/kusti8/izzati',
      author='Gustav Hansen',
      author_email='kusti8@gmail.com',
      license='GPL3',
      packages=['izzati'],
      install_requires=[
          'flask',
      ],
      keywords = 'izzati backend frontend communication simple',
      include_package_data=True,
      zip_safe=False)
